Geospatial Knowledge supporting Intelligence workflows
======================================================
Query broadcasted news worldwide and visualize them using spatial aggregations.

This modern Python module represents an idiomatic client accessing the `Geospatial Knowledge APIs <https://geospatial-ai.de/?rara_portfolio_categories=api-services>`__ being hosted on `Rapid API Hub <https://rapidapi.com/hub>`__.

Why is it important?
--------------------
Geospatial Knowledge refers to semantic information about specific locations on the Earth's surface. 
It includes location-enabled things - not strings - like physical features of the landscape, the location of cities or in general human activities, and their spatial distribution. 
Various sources like satellite imagery, location-enabled datasets, and most important any location-enabled information in the context of Open Source Intelligence (OSINT) are used to create Geospatial Knowledge. 
By analyzing location-enabled things an analyst is empowered to gain insights into various aspects of human activities.

Next steps
----------
Please, check out the `RapidAPI Account Creation and Management Guide <https://docs.rapidapi.com/docs/account-creation-and-settings>`__.

Start with the :doc:`usage` section for further information, including
how to :ref:`installation` the Python module.

.. note::

   This project is under active development.

Contents
--------

.. toctree::

   usage
   api
